package userCC

import (
	"gitlab.smartblocklab.com/smartcontracts/common/model/requests"
)

type UserStatus string

const (
	UserStatus_Moderation UserStatus = "MODERATION"
	UserStatus_Approved   UserStatus = "APPROVED"
	UserStatus_Rejected   UserStatus = "REJECTED"
	UserStatus_Blocked    UserStatus = "BLOCKED"
	UserStatus_Activated  UserStatus = "ACTIVATED"
)

type UserPublicKey struct {
	Alias     string `json:"alias"` // todo может быть удалить т.к используется User.PublicKeys
	PublicKey string `json:"public_key"`
	// We need to add signature, so we will be able to verify whenever user which publishes information
	// indeed has private key which corresponds to the public key from public key, hence user is expected
	// to sign therefore we should be able to verify signature.
	// 1. User will hash its public key
	// 2. Sign the resulted hash
	// 3. Update signature field with resulted signature
	// 4. Once we receive the information, we will be able to verify user record
	OwnerSignature     requests.UserSignature `json:"owner_signature"`
	AuthoritySignature requests.UserSignature `json:"authority_signature"`
	Revoked            bool                   `json:"revoked"`
}

type CustomerType string

const (
	Root    CustomerType = "ROOT"    // only one
	Person  CustomerType = "PERSON"  // vasya lozhkin
	Company CustomerType = "COMPANY" // org1, Cryptoneter
	System  CustomerType = "SYSTEM"  // END_USER/BEGIN_USER/LOCK_USER/MARKET_USER
	Service CustomerType = "SERVICE" // daemon_user/rest_user
)

func (c CustomerType) String() string {
	return string(c)
}

type AddPublicKeyArg struct {
	UserID     string `json:"user_id"`
	PubKeyJson string `json:"pub_key_json"`
}

type RevokeUserPublicKeyArg struct {
	UserID   string `json:"user_id"`
	KeyAlias string `json:"key_alias"`
}
